[−][src]Struct ckb_types::packed::Block
Implementations
impl Block[src]
pub const FIELD_COUNT: usize[src]
pub fn total_size(&self) -> usize[src]
pub fn field_count(&self) -> usize[src]
pub fn count_extra_fields(&self) -> usize[src]
pub fn has_extra_fields(&self) -> bool[src]
pub fn header(&self) -> Header[src]
pub fn uncles(&self) -> UncleBlockVec[src]
pub fn transactions(&self) -> TransactionVec[src]
pub fn proposals(&self) -> ProposalShortIdVec[src]
pub fn as_reader<'r>(&'r self) -> BlockReader<'r>[src]
impl Block[src]
pub fn as_advanced_builder(&self) -> BlockBuilder[src]
Creates an advanced builder base on current data.
impl Block[src]
pub fn into_view_without_reset_header(self) -> BlockView[src]
Calculates transaction associated hashes and converts them into BlockView.
Notice
BlockView created by this method could have invalid hashes or
invalid merkle roots in the header.
pub fn into_view(self) -> BlockView[src]
Calculates transaction associated hashes, resets all hashes and merkle roots in the header, then converts them into BlockView.
impl Block[src]
pub fn calc_header_hash(&self) -> Byte32[src]
Calls BlockReader.calc_header_hash() for self.as_reader().
impl Block[src]
pub fn calc_proposals_hash(&self) -> Byte32[src]
impl Block[src]
pub fn calc_uncles_hash(&self) -> Byte32[src]
Calls BlockReader.calc_uncles_hash() for self.as_reader().
impl Block[src]
pub fn calc_tx_hashes(&self) -> Vec<Byte32>[src]
Calls BlockReader.calc_tx_hashes() for self.as_reader().
impl Block[src]
pub fn calc_tx_witness_hashes(&self) -> Vec<Byte32>[src]
impl Block[src]
pub fn serialized_size_without_uncle_proposals(&self) -> usize[src]
impl Block[src]
pub fn as_uncle(&self) -> UncleBlock[src]
Converts self to an uncle block.
pub fn reset_header(self) -> Block[src]
Recalculates all hashes and merkle roots in the header.