[−][src]Struct ckb_types::packed::CellOutput
Implementations
impl CellOutput[src]
pub const FIELD_COUNT: usize[src]
pub fn total_size(&self) -> usize[src]
pub fn field_count(&self) -> usize[src]
pub fn count_extra_fields(&self) -> usize[src]
pub fn has_extra_fields(&self) -> bool[src]
pub fn capacity(&self) -> Uint64[src]
pub fn lock(&self) -> Script[src]
pub fn type_(&self) -> ScriptOpt[src]
pub fn as_reader<'r>(&'r self) -> CellOutputReader<'r>[src]
impl CellOutput[src]
pub fn calc_data_hash(data: &[u8]) -> Byte32[src]
Calculates the hash for cell data.
Returns the empty hash if no data, otherwise, calculates the hash of the data and returns it.
impl CellOutput[src]
pub fn calc_lock_hash(&self) -> Byte32[src]
impl CellOutput[src]
pub fn occupied_capacity(
&self,
data_capacity: Capacity
) -> CapacityResult<Capacity>[src]
&self,
data_capacity: Capacity
) -> CapacityResult<Capacity>
Calculates the occupied capacity of CellOutput.
Includes output_data (provided), capacity (8), lock (calculated) and type (calculated).
pub fn is_lack_of_capacity(
&self,
data_capacity: Capacity
) -> CapacityResult<bool>[src]
&self,
data_capacity: Capacity
) -> CapacityResult<bool>
Returns if the capacity in CellOutput is smaller than the occupied capacity.